summaryrefslogtreecommitdiffstats
path: root/src/xml/qxml.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 16:44:56 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 16:44:56 -0600
commitceaf41bd779bdcc293a4f43100a3834c72c2c46d (patch)
treeeb429d42c0ab5b5404d65e79ab4e9884775f0614 /src/xml/qxml.cpp
parent5dea938f814eff53a106e572c98620ecd0043bd9 (diff)
downloadtqt3-ceaf41bd779bdcc293a4f43100a3834c72c2c46d.tar.gz
tqt3-ceaf41bd779bdcc293a4f43100a3834c72c2c46d.zip
Update from latest conversion script
Diffstat (limited to 'src/xml/qxml.cpp')
-rw-r--r--src/xml/qxml.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/xml/qxml.cpp b/src/xml/qxml.cpp
index 3fdbd755..fb09a89f 100644
--- a/src/xml/qxml.cpp
+++ b/src/xml/qxml.cpp
@@ -1838,7 +1838,7 @@ TQString TQXmlInputSource::fromRawData( const TQByteArray &data, bool beginning
and the name of the attribute in \a aName. It passes a string that
represents the attribute type in \a type and a string that
represents the attribute default in \a valueDefault. This string
- is one of "#IMPLIED", "#RETQUIRED", "#FIXED" or TQString::null (if
+ is one of "#IMPLIED", "#REQUIRED", "#FIXED" or TQString::null (if
none of the others applies). The reader passes the attribute's
default value in \a value. If no default value is specified in the
XML file, \a value is TQString::null.
@@ -5068,7 +5068,7 @@ bool TQXmlSimpleReader::parseAttlistDecl()
const signed char Atttype = 7; // parse the AttType
const signed char Ws3 = 8; // whitespace read
const signed char DDecH = 9; // DefaultDecl with #
- const signed char DefReq = 10; // parse the string "RETQUIRED"
+ const signed char DefReq = 10; // parse the string "REQUIRED"
const signed char DefImp = 11; // parse the string "IMPLIED"
const signed char DefFix = 12; // parse the string "FIXED"
const signed char Attval = 13; // parse the AttValue
@@ -5207,7 +5207,7 @@ bool TQXmlSimpleReader::parseAttlistDecl()
next();
break;
case DefReq:
- d->parseString_s = "RETQUIRED";
+ d->parseString_s = "REQUIRED";
if ( !parseString() ) {
parseFailed( &TQXmlSimpleReader::parseAttlistDecl, state );
return FALSE;